# Pyreusion
* Common method integration in the process of Python programming.
    * 对在python编程过程中常用的方法进行整合封装。

## Requirement
* Python 3.6+

## Setup
* pip
   * pip install pyreusion
* git
   * git clone https://github.com/Arludesi/pyreusion.git
   * run setup.bat
* source code
   * git & paste pyreusion.py to site-packages folder.

